@@ -20,16 +20,17 @@
 #include "componentsdialog_p.h"
 #include <klocalizedstring.h>
 #include <QDialogButtonBox>
-#include <QLayout>
 #include <QLabel>
 #include <QPushButton>
 #include <kplugininfo.h>
 #include <kiconloader.h>
 #include <QDebug>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 #include <kconfig.h>
 #include <kseparator.h>
 
-#include <QtCore/QList>
+#include <QList>
 #include <QTreeWidget>
 
 namespace KSettings
@@ -68,7 +69,7 @@ ComponentsDialog::ComponentsDialog(QWidget *parent, const char *name)
     layout->addWidget(buttonBox);
 
     QHBoxLayout *hbox = new QHBoxLayout(page);
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
 
     d->listview = new QTreeWidget(page);
     d->listview->setMinimumSize(200, 200);
@@ -76,7 +77,7 @@ ComponentsDialog::ComponentsDialog(QWidget *parent, const char *name)
     d->infowidget->setMinimumSize(200, 200);
 
     QVBoxLayout *vbox = new QVBoxLayout(d->infowidget);
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
 
     d->iconwidget = new QLabel(d->infowidget);
     vbox->addWidget(d->iconwidget);
@@ -134,7 +135,7 @@ void ComponentsDialog::show()
         (*it)->load();
         QTreeWidgetItem *item = new QTreeWidgetItem(d->listview, QStringList((*it)->name()));
         if (!(*it)->icon().isEmpty()) {
-            item->setIcon(0, SmallIcon((*it)->icon(), IconSize(KIconLoader::Small)));
+            item->setIcon(0, QIcon::fromTheme((*it)->icon()));
         }
         item->setCheckState(0, (*it)->isPluginEnabled() ? Qt::Checked : Qt::Unchecked);
         d->plugininfomap[ item ] = (*it);
@@ -158,7 +159,7 @@ void ComponentsDialog::executed(QTreeWidgetItem *item, int)
     info->setPluginEnabled(checked);
     //checkDependencies( info );
     // show info about the component on the right
-    d->iconwidget->setPixmap(SmallIcon(info->icon(), KIconLoader::SizeLarge));
+    d->iconwidget->setPixmap(QIcon::fromTheme(info->icon()).pixmap(style()->pixelMetric(QStyle::PM_MessageBoxIconSize)));
     d->commentwidget->setText(info->comment());
     //d->descriptionwidget->setText( info->description() );
 }
